@@ -1,30 +1,46 @@
-import numpy as np
-import Shadow as sd
-import matplotlib.pyplot as plt
-from matplotlib import cm
-from matplotlib import figure as matfig
-import pylab
-import matplotlib
-import ShadowToolsPrivate as stp
-from ShadowToolsPrivate import Histo1_Ticket as Histo1_Ticket
-from ShadowToolsPrivate import plotxy_Ticket as plotxy_Ticket
+from __future__ import print_function
+import numpy 
+import Shadow.ShadowLibExtensions as sd
+import sys
+try: 
+    #import matplotlib.pyplot as plt
+    #from matplotlib import cm
+    #from matplotlib import figure as matfig
+    #import pylab
+    #import matplotlib
+    import matplotlib
+    import matplotlib.pyplot as plt
+    from matplotlib import cm
+    from matplotlib import figure as matfig
+    import pylab
+except ImportError: 
+    print(sys.exc_info()[1]) 
+    pass
+
+import Shadow.ShadowToolsPrivate as stp
+from Shadow.ShadowToolsPrivate import Histo1_Ticket as Histo1_Ticket
+from Shadow.ShadowToolsPrivate import plotxy_Ticket as plotxy_Ticket
 import os
 
-A2EV = 50676.89919462
+#A2EV = 50676.89919462
+codata_h = numpy.array(6.62606957e-34)
+codata_ec = numpy.array(1.602176565e-19)
+codata_c = numpy.array(299792458.0)
+A2EV = 2.0*numpy.pi/(codata_h*codata_c/codata_ec*1e2)
 
 def getshonecol(beam,col):
-  '''
+  """
   Extract a column from a shadow file (eg. begin.dat) or a Shadow.Beam instance. 
   The column are numbered in the fortran convention, i.e. starting from 1.
   It returns a numpy.array filled with the values of the chosen column.
   
-  Inputs:
+  Inumpy.ts:
      beam     : str instance with the name of the shadow file to be loaded. OR
                 Shadow.Beam initialized instance.
      col      : int for the chosen columns.
      
   Outputs:
-     numpy.array 1-D with length NPOINT.
+     numpy.array 1-D with length numpy.INT.
      
   Error:
      if an error occurs an ArgsError is raised.
@@ -63,7 +79,7 @@ def getshonecol(beam,col):
           31   S1-stokes = |Es|^2 - |Ep|^2
           32   S2-stokes = 2 |Es| |Ep| cos(phase_s-phase_p)
           33   S3-stokes = 2 |Es| |Ep| sin(phase_s-phase_p)
-  '''
+  """
   try: stp.getshonecol_CheckArg(beam,col)
   except stp.ArgsError as e: raise e
   col=col-1
@@ -75,52 +91,52 @@ def getshonecol(beam,col):
     ray = bm.rays
   if col>=0 and col<18 and col!=10:  column =  ray[:,col]
   if col==10: column =  ray[:,col]/A2EV
-  if col==18: column =  2*np.pi*1.0e8/ray[:,10]
-  if col==19: column =  np.sqrt(ray[:,0]*ray[:,0]+ray[:,1]*ray[:,1]+ray[:,2]*ray[:,2])
-  if col==20: column =  np.arccos(ray[:,4])
-  if col==21: column =  np.sqrt(np.sum(np.array([ ray[:,i]*ray[:,i] for i in [6,7,8,15,16,17] ]),axis=0))
-  if col==22: column =  np.sum(np.array([ ray[:,i]*ray[:,i] for i in [6,7,8,15,16,17] ]),axis=0)
-  if col==23: column =  np.sum(np.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
-  if col==24: column =  np.sum(np.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
+  if col==18: column =  2*numpy.pi*1.0e8/ray[:,10]
+  if col==19: column =  numpy.sqrt(ray[:,0]*ray[:,0]+ray[:,1]*ray[:,1]+ray[:,2]*ray[:,2])
+  if col==20: column =  numpy.arccos(ray[:,4])
+  if col==21: column =  numpy.sqrt(numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [6,7,8,15,16,17] ]),axis=0))
+  if col==22: column =  numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [6,7,8,15,16,17] ]),axis=0)
+  if col==23: column =  numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
+  if col==24: column =  numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
   if col==25: column =  ray[:,10]*1.0e8
   if col==26: column =  ray[:,3]*ray[:,10]*1.0e8
   if col==27: column =  ray[:,4]*ray[:,10]*1.0e8
   if col==28: column =  ray[:,5]*ray[:,10]*1.0e8
   if col==29:
-    E2s = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
-    E2p = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
+    E2s = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
+    E2p = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
     column =  E2p+E2s    
   if col==30:
-    E2s = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
-    E2p = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
+    E2s = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
+    E2p = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
     column =  E2p-E2s
   if col==31:
-    E2s = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
-    E2p = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
-    Cos = np.cos(ray[:,13]-ray[:,14])
+    E2s = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
+    E2p = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
+    Cos = numpy.cos(ray[:,13]-ray[:,14])
     column =  2*E2s*E2p*Cos
   if col==32:
-    E2s = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
-    E2p = np.sum(np.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
-    Sin = np.sin(ray[:,13]-ray[:,14])
+    E2s = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [6,7,8] ]),axis=0)
+    E2p = numpy.sum(numpy.array([ ray[:,i]*ray[:,i] for i in [15,16,17] ]),axis=0)
+    Sin = numpy.sin(ray[:,13]-ray[:,14])
     column =  2*E2s*E2p*Sin
   return column
 
 
 
 def getshcol(beam,col):
-  '''
-  Extract multiple columns from a shadow file (eg.'begin.dat') or a Shadow.Beam instance. 
+  """
+  Extract multiple columns from a shadow file (eg."begin.dat") or a Shadow.Beam instance. 
   The column are numbered in the fortran convention, i.e. starting from 1.
-  It returns a np.array filled with the values of the chosen column.
+  It returns a numpy.array filled with the values of the chosen column.
   
-  Inputs:
+  Inumpy.ts:
      beam     : str instance with the name of the shadow file to be loaded. OR
                 Shadow.Beam initialized instance.
      col      : tuple or list instance of int with the number of columns chosen.
      
   Outputs:
-     numpy.array 2-D with dimension R x NPOINT. Where R is the total number of column chosen
+     numpy.array 2-D with dimension R x numpy.INT. Where R is the total number of column chosen
      
   Error:
      if an error occurs an ArgsError is raised.      
@@ -159,7 +175,7 @@ def getshcol(beam,col):
           31   S1-stokes = |Es|^2 - |Ep|^2
           32   S2-stokes = 2 |Es| |Ep| cos(phase_s-phase_p)
           33   S3-stokes = 2 |Es| |Ep| sin(phase_s-phase_p)
-  '''
+  """
   try: stp.getshcol_CheckArg(beam,col)
   except stp.ArgsError as e: raise e
   if isinstance(beam,sd.Beam):
@@ -173,16 +189,16 @@ def getshcol(beam,col):
     ret.append(getshonecol(bm,c))
   return tuple(ret)
 
-def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,title='HISTO1',xtitle=None,ytitle=None,calfwhm=0,noplot=0):
-  '''
+def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,title="HISTO1",xtitle=None,ytitle=None,calfwhm=0,noplot=0):
+  """
   Plot the histogram of a column, simply counting the rays, or weighting with the intensity.
   It returns a ShadowTools.Histo1_Ticket which contains the histogram data, and the figure.
   
-  Inputs:
+  Inumpy.ts:
      beam     : str instance with the name of the shadow file to be loaded, or a Shadow.Beam initialized instance.
      col      : int for the chosen column.
   
-  Optional Inputs:
+  Optional Inumpy.ts:
      xrange   : tuple or list of length 2 describing the interval of interest for x, the data read from the chosen column.
      yrange   : tuple or list of length 2 describing the interval of interest for y, counts or intensity depending on ref.
      nbins    : number of bins of the histogram.
@@ -195,7 +211,7 @@ def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,titl
            1   weight with intensity (look at 23 |E|^2 total intensity)
      write    : 
            0   don't write any file
-           1   write the histogram into the file 'HISTO1'.
+           1   write the histogram into the file "HISTO1".
      title    : title of the figure, it will appear on top of the window.
      xtitle   : label for the x axis.
      ytitle   : label for the y axis.
@@ -206,8 +222,8 @@ def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,titl
            0   plot the histogram
            1   don't plot the histogram
   orientation :
-  'vertical'   x axis for data, y for intensity
-'horizontal'   y axis for data, x for intensity
+  "vertical"   x axis for data, y for intensity
+  "horizontal"   y axis for data, x for intensity
      plotxy   : 
            0   standalone version
            1   to use within plotxy
@@ -251,7 +267,7 @@ def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,titl
           31   S1-stokes = |Es|^2 - |Ep|^2
           32   S2-stokes = 2 |Es| |Ep| cos(phase_s-phase_p)
           33   S3-stokes = 2 |Es| |Ep| sin(phase_s-phase_p)
-  '''
+  """
   try: stp.Histo1_CheckArg(beam,col,xrange,yrange,nbins,nolost,ref,write,title,xtitle,ytitle,calfwhm,noplot)
   except stp.ArgsError as e: raise e  
   col=col-1
@@ -267,36 +283,36 @@ def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,titl
     ytitlesave=None
   if ref==0: 
     x, a = getshcol(beam,(col+1,10))
-    w = np.ones(len(x))
+    w = numpy.ones(len(x))
   else:
     x, a, w = getshcol(beam,(col+1,10,ref))
   if nolost==0: 
-    t = np.where(a!=-3299)
-    ytitle = 'All rays'
+    t = numpy.where(a!=-3299)
+    ytitle = "All rays"
   if nolost==1: 
-    t = np.where(a==1.0)
-    ytitle = 'Good rays'
+    t = numpy.where(a==1.0)
+    ytitle = "Good rays"
   if nolost==2: 
-    t = np.where(a!=1.0)
-    ytitle = 'Lost rays'
+    t = numpy.where(a!=1.0)
+    ytitle = "Lost rays"
   if len(t[0])==0:
-    print "no rays match the selection, the histogram will not be plotted"
+    print ("no rays match the selection, the histogram will not be plotted")
     return 
   if ref==0:
-    ytitle = 'counts ' + ytitle
-    h,bins,patches = axHist.hist(x[t],bins=nbins,histtype='step',alpha=0.5)
-    if yrange==None: yrange = [0.0, np.max(h)*1.1]
+    ytitle = "counts " + ytitle
+    h,bins,patches = axHist.hist(x[t],bins=nbins,range=xrange,histtype="step",alpha=0.5)
+    if yrange==None: yrange = [0.0, numpy.max(h)*1.1]
     hw=h
   if ref>=22: 
-    ytitle = (stp.getLabel(ref-1))[0] + ' ' + ytitle
-    h,bins = np.histogram(x[t],bins=nbins)
-    hw,bins,patches = axHist.hist(x[t],bins=nbins,histtype='step',alpha=0.5,weights=w[t])
-    if yrange==None: yrange = [0.0, np.max(hw)*1.1]
+    ytitle = (stp.getLabel(ref-1))[0] + " " + ytitle
+    h,bins = numpy.histogram(x[t],range=xrange,bins=nbins)
+    hw,bins,patches = axHist.hist(x[t],range=xrange, bins=nbins,histtype="step",alpha=0.5,weights=w[t])
+    if yrange==None: yrange = [0.0, numpy.max(hw)*1.1]
   fwhm = None
   if calfwhm==1:
-    fwhm, tf, ti = stp.calcFWHM(h,bins[1]-bins[0])
-    axHist.plot([bins[ti],bins[tf+1]],[max(h)*0.5,max(h)*0.5],'x-')
-    print "fwhm = ", fwhm
+    fwhm, tf, ti = stp.calcFWHM(hw,bins[1]-bins[0])
+    axHist.plot([bins[ti],bins[tf+1]],[max(h)*0.5,max(h)*0.5],"x-")
+    print ("fwhm = %g" % fwhm)
   if write==1: stp.Histo1_write(title,bins,h,hw,col,beam,ref-1)  
 
   if xtitle==None: xtitle=(stp.getLabel(col))[0]
@@ -314,7 +330,7 @@ def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,titl
     figure.show()  
   
   ticket = Histo1_Ticket()    
-  ticket.histogram = h
+  ticket.histogram = hw
   ticket.bin_center = bins[:-1]+(bins[1]-bins[0])*0.5
   ticket.bin_left = bins[:-1] 
   ticket.figure = figure
@@ -324,20 +340,21 @@ def histo1(beam,col,xrange=None,yrange=None,nbins=50,nolost=0,ref=0,write=0,titl
   ticket.ytitle = ytitle
   ticket.title = title
   ticket.fwhm = fwhm
+  ticket.intensity = w[t].sum()
   return ticket
  
 
 
 
-def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=None,nolost=0,title='PLOTXY',xtitle=None,ytitle=None,noplot=0,calfwhm=0,contour=0):
-  '''
+def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=None,nolost=0,title="PLOTXY",xtitle=None,ytitle=None,noplot=0,calfwhm=0,contour=0):
+  """
   Draw the scatter or contour or pixel-like plot of two columns of a Shadow.Beam instance or of a given shadow file, along with histograms for the intensity on the top and right side.
-  Inputs:
+  Inumpy.ts:
      beam     : str instance with the name of the shadow file to be loaded, or a Shadow.Beam initialized instance.
      cols1    : first column.
      cols2    : second column.
   
-  Optional Inputs:
+  Optional Inumpy.ts:
      nbins    : int for the size of the grid (nbins x nbins). It will affect the plot only if non scatter.
      nbins_h  : int for the number of bins for the histograms
      level    : int number of level to be drawn. It will affect the plot only if contour.
@@ -356,6 +373,8 @@ def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=Non
      calfwhm :
            0   don't compute the fwhm
            1   compute the fwhm and draw it
+           2   in addition to calfwhm=1, it computes now the intensity in a
+               slit of FWHM_h x FWHM_v
      contour  :
            0   scatter plot
            1   contour, black & white, only counts (without intensity)
@@ -404,7 +423,7 @@ def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=Non
           31   S1-stokes = |Es|^2 - |Ep|^2
           32   S2-stokes = 2 |Es| |Ep| cos(phase_s-phase_p)
           33   S3-stokes = 2 |Es| |Ep| sin(phase_s-phase_p)
-  '''
+  """
   if nbins_h==None: nbins_h=nbins+1
   try: 
     stp.plotxy_CheckArg(beam,cols1,cols2,nbins,nbins_h,level,xrange,yrange,nolost,title,xtitle,ytitle,noplot,calfwhm,contour)
@@ -417,21 +436,21 @@ def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=Non
   if xtitle==None: xtitle=(stp.getLabel(cols1-1))[0]
   if ytitle==None: ytitle=(stp.getLabel(cols2-1))[0]
   
-  if nolost==0: t = np.where(col3!=-3299)
-  if nolost==1: t = np.where(col3==1.0)
-  if nolost==2: t = np.where(col3!=1.0)  
+  if nolost==0: t = numpy.where(col3!=-3299)
+  if nolost==1: t = numpy.where(col3==1.0)
+  if nolost==2: t = numpy.where(col3!=1.0)  
 
   if xrange==None: xrange = stp.setGoodRange(col1[t])
   if yrange==None: yrange = stp.setGoodRange(col2[t])
   #print xrange
   #print yrange
-  tx = np.where((col1>xrange[0])&(col1<xrange[1]))
-  ty = np.where((col2>yrange[0])&(col2<yrange[1]))
+  tx = numpy.where((col1>xrange[0])&(col1<xrange[1]))
+  ty = numpy.where((col2>yrange[0])&(col2<yrange[1]))
   
   tf = set(list(t[0])) & set(list(tx[0])) & set(list(ty[0]))
-  t = (np.array(sorted(list(tf))),)
+  t = (numpy.array(sorted(list(tf))),)
   if len(t[0])==0: 
-    print "no point selected"
+    print ("no point selected")
     return None
   
   figure = pylab.plt.figure(figsize=(12,8),dpi=96)
@@ -455,9 +474,9 @@ def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=Non
   if contour==0:
     axScatter.scatter(col1[t],col2[t],s=0.5)
   if contour>0 and contour<7:
-    if contour==1 or contour==3 or contour==5: w = np.ones( len(col1) )
+    if contour==1 or contour==3 or contour==5: w = numpy.ones( len(col1) )
     if contour==2 or contour==4 or contour==6: w = col4
-    grid = np.zeros(nbins*nbins).reshape(nbins,nbins)
+    grid = numpy.zeros(nbins*nbins).reshape(nbins,nbins)
     for i in t[0]:
       indX = stp.findIndex(col1[i],nbins,xrange[0],xrange[1])
       indY = stp.findIndex(col2[i],nbins,yrange[0],yrange[1])
@@ -465,9 +484,9 @@ def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=Non
         grid[indX][indY] = grid[indX][indY] + w[i]
       except IndexError:
         pass
-    X, Y = np.mgrid[xrange[0]:xrange[1]:nbins*1.0j,yrange[0]:yrange[1]:nbins*1.0j]
-    L = np.linspace(np.amin(grid),np.amax(grid),level)
-    if contour==1 or contour==2: axScatter.contour(X, Y, grid, colors='k', levels=L)
+    X, Y = numpy.mgrid[xrange[0]:xrange[1]:nbins*1.0j,yrange[0]:yrange[1]:nbins*1.0j]
+    L = numpy.linspace(numpy.amin(grid),numpy.amax(grid),level)
+    if contour==1 or contour==2: axScatter.contour(X, Y, grid, colors="k", levels=L)
     if contour==3 or contour==4: axScatter.contour(X, Y, grid, levels=L)
     if contour==5 or contour==6: axScatter.pcolor(X, Y, grid)  
   #axScatter.set_xlim(xrange)
@@ -477,68 +496,68 @@ def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=Non
   #axScatter.axis(ymin=yrange[0],ymax=yrange[1])
   
   for tt in axScatter.get_xticklabels():
-    tt.set_size('x-small')
+    tt.set_size("x-small")
   for tt in axScatter.get_yticklabels():
-    tt.set_size('x-small')
+    tt.set_size("x-small")
   
-  #if ref==0: col4 = np.ones(len(col4),dtype=float)
+  #if ref==0: col4 = numpy.ones(len(col4),dtype=float)
   
   axHistx = figure.add_axes(rect_histx, sharex=axScatter)
   axHisty = figure.add_axes(rect_histy, sharey=axScatter)
   
-  binx = np.linspace(xrange[0],xrange[1],nbins_h)
-  biny = np.linspace(yrange[0],yrange[1],nbins_h)
+  binx = numpy.linspace(xrange[0],xrange[1],nbins_h)
+  biny = numpy.linspace(yrange[0],yrange[1],nbins_h)
   if contour==0 or contour==1 or contour==3 or contour==5:
-    hx, binx, patchx = axHistx.hist(col1[t],bins=binx,histtype='step',color='k')
-    hy, biny, patchy = axHisty.hist(col2[t],bins=biny,orientation='horizontal',histtype='step',color='k')
+    hx, binx, patchx = axHistx.hist(col1[t],bins=binx,range=xrange,histtype="step",color="k")
+    hy, biny, patchy = axHisty.hist(col2[t],bins=biny,range=yrange,orientation="horizontal",histtype="step",color="k")
   if contour==2 or contour==4 or contour==6:
-    hx, binx, patchx = axHistx.hist(col1[t],bins=binx,weights=col4[t],histtype='step',color='b')
-    hy, biny, patchy = axHisty.hist(col2[t],bins=biny,weights=col4[t],orientation='horizontal',histtype='step',color='b')
+    hx, binx, patchx = axHistx.hist(col1[t],bins=binx,range=xrange,weights=col4[t],histtype="step",color="b")
+    hy, biny, patchy = axHisty.hist(col2[t],bins=biny,range=yrange,weights=col4[t],orientation="horizontal",histtype="step",color="b")
   for tl in axHistx.get_xticklabels(): tl.set_visible(False)
   for tl in axHisty.get_yticklabels(): tl.set_visible(False)
   for tt in axHisty.get_xticklabels():
     tt.set_rotation(270)
-    tt.set_size('x-small')
+    tt.set_size("x-small")
   for tt in axHistx.get_yticklabels():
-    tt.set_size('x-small')
+    tt.set_size("x-small")
 
   intensityinslit = 0.0
   if calfwhm>=1:
     fwhmx,txf, txi = stp.calcFWHM(hx,binx[1]-binx[0])
     fwhmy,tyf, tyi = stp.calcFWHM(hy,biny[1]-biny[0])
-    axHistx.plot([binx[txi],binx[txf+1]],[max(hx)*0.5,max(hx)*0.5],'x-')
-    axHisty.plot([max(hy)*0.5,max(hy)*0.5],[biny[tyi],biny[tyf+1]],'x-')
-    print "fwhm horizontal:  ", fwhmx
-    print "fwhm vertical:    ", fwhmy
+    axHistx.plot([binx[txi],binx[txf+1]],[max(hx)*0.5,max(hx)*0.5],"x-")
+    axHisty.plot([max(hy)*0.5,max(hy)*0.5],[biny[tyi],biny[tyf+1]],"x-")
+    print ("fwhm horizontal:  %g" % fwhmx)
+    print ("fwhm vertical:    %g" % fwhmy)
   if calfwhm>=2:
     xx1 = binx[txi]
     xx2 = binx[txf+1]
     yy1 = biny[tyi]
     yy2 = biny[tyf+1]
-    print "limits horizontal:  ", binx[txi],binx[txf+1]
-    print "limits vertical:  ", biny[tyi],biny[tyf+1]
+    print ("limits horizontal: %g %g " % (binx[txi],binx[txf+1]))
+    print ("limits vertical:   %g %g " % (biny[tyi],biny[tyf+1]))
     axScatter.plot([xx1,xx2,xx2,xx1,xx1],[yy1,yy1,yy2,yy2,yy1])
     #fwhmx,txf, txi = stp.calcFWHM(hx,binx[1]-binx[0])
     #fwhmy,tyf, tyi = stp.calcFWHM(hy,biny[1]-biny[0])
     #calculate intensity in slit
-    if nolost==0: tt = np.where(col3!=-3299)
-    if nolost==1: tt = np.where(col3==1.0)
-    if nolost==2: tt = np.where(col3!=1.0)  
+    if nolost==0: tt = numpy.where(col3!=-3299)
+    if nolost==1: tt = numpy.where(col3==1.0)
+    if nolost==2: tt = numpy.where(col3!=1.0)  
 
-    ttx = np.where((col1>=xx1)&(col1<=xx2))
-    tty = np.where((col2>=yy1)&(col2<=yy2))
+    ttx = numpy.where((col1>=xx1)&(col1<=xx2))
+    tty = numpy.where((col2>=yy1)&(col2<=yy2))
   
     ttf = set(list(tt[0])) & set(list(ttx[0])) & set(list(tty[0]))
-    tt = (np.array(sorted(list(ttf))),)
+    tt = (numpy.array(sorted(list(ttf))),)
     if len(tt[0])>0: 
       intensityinslit = col4[tt].sum()
-      print "Intensity in slit: ",intensityinslit
+      print ("Intensity in slit: %g ",intensityinslit)
     
   if title!=None:
     axHistx.set_title(title)
   axText = figure.add_axes(rect_text)
-  ntot = len(np.where(col3!=3299)[0])
-  ngood = len(np.where(col3==1)[0])
+  ntot = len(numpy.where(col3!=3299)[0])
+  ngood = len(numpy.where(col3==1)[0])
   nbad = ntot - ngood
   if nolost==0: axText.text(0.0,0.8,"ALL RAYS")
   if nolost==1: axText.text(0.0,0.8,"GOOD RAYS")
@@ -570,6 +589,8 @@ def plotxy(beam,cols1,cols2,nbins=25,nbins_h=None,level=5,xrange=None,yrange=Non
     ticket.fwhmx = fwhmx
     ticket.fwhmy = fwhmy
   ticket.intensity = col4[t].sum()
+  ticket.averagex = numpy.average( col1[t] )
+  ticket.averagey = numpy.average( col2[t] )
   ticket.intensityinslit = intensityinslit
   return ticket  
   
@@ -580,8 +601,8 @@ if __name__=="__main__":
   a.load("begin.dat")
   ticket1 = histo1(a,1,nbins=25,noplot=1,calfwhm=1)
   ticket1.figure.show()
-  raw_input()
+  raw_inumpy.t()
   ticket1 = plotxy(a,(1,3),noplot=1)
   ticket1.figure.show()
-  raw_input()
+  raw_inumpy.t()
 
